from django.core.exceptions import ValidationError


def valid_extension(value):
    """
    Function that valid extension
    when upload file in form
    """
    if (not value.name.endswith('.png') and
        not value.name.endswith('.jpeg') and
        not value.name.endswith('.gif') and
        not value.name.endswith('.bmp') and
        not value.name.endswith('.jpg')):

        text = "Files allowed"
        files = ".jpg, .jpeg, .png, .gif, .bmp"
        raise ValidationError(text + ': ' + files)


import sys

from django import template
from django.conf import settings
from django.shortcuts import get_object_or_404
from django.utils.safestring import mark_safe

from ..models import Advertising

register = template.Library()


@register.simple_tag
def get_images_advertising(width=100, height=100, *args, **kwargs):
    """
    @method: get_images_advertising
    @descrip: Method thar return images advertising
    @param width: width img
    @param height: height img
    """

    if 'campaign' in kwargs:
        campaign = kwargs['campaign']
    else:
        campaign = None

    if sys.version_info >= (3, 0):
        if not isinstance(width, str):
            width = str(width)
    else:
        if not isinstance(width, basestring):
            width = str(width)

    if sys.version_info >= (3, 0):
        if not isinstance(height, str):
            height = str(height)
    else:
        if not isinstance(height, basestring):
            height = str(height)

    if campaign is None:
        try:
            data = Advertising.objects.all()[0]
        except Advertising.DoesNotExist:
            data = None
    else:
        try:
            data = Advertising.objects.get(id_advertising=campaign)
        except Advertising.DoesNotExist:
            data = None

    html = ""

    if data:
        if data.timeout:
            id_adv = data.id_advertising.strip()
            timeout = data.timeout * 1000
            html += """
                <script>
                window.TimeOutAdvertising_""" + id_adv + """ = """ + str(timeout) + """
                </script>"""

        html += """
            <style>
            .parent_advertising {
            position: relative;
            width: """ + width + """px;
            height: """ + height + """px;
            }
            .img_advertising {
            position: absolute;
            width: """ + width + """px;
            height: """ + height + """px;
            }
            </style>
        """

        if hasattr(data, 'images'):
            html += '<div id="images_advertising_' + id_adv + '"'
            html += ' class="parent_advertising">'
            counter = 0
            for image in data.images.all():
                html += '<div id="image_container_advertising_' + str(counter)
                html += '_' + id_adv + '"'
                html += ' <a href="' + image.url + '">'
                html += '<img src="' + settings.MEDIA_URL + str(image.photo)
                html += '" class="img_advertising"'
                html += ' id="img_advertising_' + str(counter) + '_' + id_adv
                html += '"></a>'
                html += '</div>'
                counter = counter + 1
            html += '</div>'

            html += """
            <script>
            document.addEventListener("DOMContentLoaded", function(event) { 
                advertisingModule.initialize('""" + id_adv + """');
            });
            </script>
            """
    else:
        html = ""

    return mark_safe(html)



from django.contrib import admin
from .models import Advertising, ImageAdvertising


class ImageAdvertisingInline(admin.TabularInline):
    """
    Inline de fotos de artículos
    """
    model = ImageAdvertising
    extra = 3


class AdvertisingAdmin(admin.ModelAdmin):
    list_display = ('id', 'name')
    list_filter = ['id', 'name']
    search_fields = ['id', 'name']
    inlines = [ImageAdvertisingInline, ]


admin.site.register(Advertising, AdvertisingAdmin)


import os

from django.db import models
from django.utils.encoding import python_2_unicode_compatible

from .validators import valid_extension


@python_2_unicode_compatible
class Advertising(models.Model):

    id_advertising = models.CharField(unique=True, max_length=10)
    name = models.CharField(max_length=80)
    timeout = models.PositiveIntegerField(
        default=0, help_text="The input value is in seconds"
    )

    class Meta(object):
        ordering = ['id_advertising']
        verbose_name = "Advertising"
        verbose_name_plural = "Advertising"

        def __str__(self):
            return self.name


@python_2_unicode_compatible
class ImageAdvertising(models.Model):

    def generate_path(instance, filename):
        folder = "campaign_" + str(instance.advertising.id)
        return os.path.join("campaigns", folder, filename)

    advertising = models.ForeignKey(Advertising, related_name='images')
    title = models.CharField(max_length=80)
    url = models.URLField(max_length=450)
    photo = models.FileField("Photo", blank=False, null=False,
                             upload_to=generate_path,
                             validators=[valid_extension])

    def __str__(self):
        return self.advertising.name
